==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/DelayedRender.js <==
import './node_modules/core-js/modules/es.date.to-string.js';
import './node_modules/core-js/modules/es.object.to-string.js';
import './node_modules/core-js/modules/es.reflect.construct.js';
import './node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import Vue from 'vue';
import './node_modules/core-js/modules/es.number.constructor.js';
import './node_modules/core-js/modules/web.timers.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var DelayedRender = function (_Vue) {
  _inherits(DelayedRender, _Vue);

  var _super = _createSuper(DelayedRender);

  function DelayedRender() {
    var _this;

    _classCallCheck(this, DelayedRender);

    _this = _super.apply(this, arguments);
    _this.isRendered = false;
    return _this;
  }

  _createClass(DelayedRender, [{
    key: "mounted",
    value: function mounted() {
      var _this2 = this;

      this.timeoutId = setTimeout(function () {
        _this2.isRendered = true;
      }, this.delay);
    }
  }, {
    key: "beforeDestroy",
    value: function beforeDestroy() {
      if (this.timeoutId) clearTimeout(this.timeoutId);
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      return this.isRendered ? h("div", [this.$slots["default"]]) : null;
    }
  }]);

  return DelayedRender;
}(Vue);

__decorate([Prop({
  type: Number,
  "default": 0
}), __metadata("design:type", Number)], DelayedRender.prototype, "delay", void 0);

DelayedRender = __decorate([Component], DelayedRender);

export { DelayedRender };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/DelayedRender.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import Vue from 'vue';
import 'core-js/modules/es.number.constructor';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var DelayedRender = function (_Vue) {
  _inherits(DelayedRender, _Vue);

  var _super = _createSuper(DelayedRender);

  function DelayedRender() {
    var _this;

    _classCallCheck(this, DelayedRender);

    _this = _super.apply(this, arguments);
    _this.isRendered = false;
    return _this;
  }

  _createClass(DelayedRender, [{
    key: "mounted",
    value: function mounted() {
      var _this2 = this;

      this.timeoutId = setTimeout(function () {
        _this2.isRendered = true;
      }, this.delay);
    }
  }, {
    key: "beforeDestroy",
    value: function beforeDestroy() {
      if (this.timeoutId) clearTimeout(this.timeoutId);
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      return this.isRendered ? h("div", [this.$slots.default]) : null;
    }
  }]);

  return DelayedRender;
}(Vue);

__decorate([Prop({
  type: Number,
  default: 0
}), __metadata("design:type", Number)], DelayedRender.prototype, "delay", void 0);

DelayedRender = __decorate([Component], DelayedRender);

export { DelayedRender };
